"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sendProofRequest = exports.isParameterizable = exports.hasPredicates = exports.findProofRequestMessage = exports.createConnectionlessProofRequestInvitation = exports.buildProofRequestDataForTemplate = void 0;
var _anoncreds = require("@aries-framework/anoncreds");
var _core = require("@aries-framework/core");
var _proofReqeustTemplate = require("../types/proof-reqeust-template");
const protocolVersion = 'v2';
const domain = 'http://aries-mobile-agent.com';

/*
 * Find Proof Request message in the storage by the given id
 * */
const findProofRequestMessage = async (agent, id) => {
  const message = await agent.proofs.findRequestMessage(id);
  if (message && message instanceof _anoncreds.V1RequestPresentationMessage && message.indyProofRequest) {
    return message.indyProofRequest;
  } else {
    return undefined;
  }
};

/*
 * Build Proof Request data from for provided template
 * */
/*
 * Build Proof Request data for provided template
 * */
exports.findProofRequestMessage = findProofRequestMessage;
const buildProofRequestDataForTemplate = (template, customValues) => {
  if (template.payload.type === _proofReqeustTemplate.ProofRequestType.AnonCreds) {
    const requestedAttributes = {};
    const requestedPredicates = {};
    let index = 0;
    template.payload.data.forEach(data => {
      var _data$requestedAttrib, _data$requestedPredic;
      if ((_data$requestedAttrib = data.requestedAttributes) !== null && _data$requestedAttrib !== void 0 && _data$requestedAttrib.length) {
        data.requestedAttributes.forEach(requestedAttribute => {
          requestedAttributes[`referent_${index}`] = {
            name: requestedAttribute.name,
            names: requestedAttribute.names,
            non_revoked: requestedAttribute.nonRevoked,
            restrictions: requestedAttribute.restrictions
          };
          index++;
        });
      }
      if ((_data$requestedPredic = data.requestedPredicates) !== null && _data$requestedPredic !== void 0 && _data$requestedPredic.length) {
        data.requestedPredicates.forEach(requestedPredicate => {
          const customValue = customValues && customValues[data.schema] ? customValues[data.schema][requestedPredicate.name] : undefined;
          requestedPredicates[`referent_${index}`] = {
            name: requestedPredicate.name,
            p_value: requestedPredicate.parameterizable && customValue ? customValue : requestedPredicate.predicateValue,
            p_type: requestedPredicate.predicateType,
            non_revoked: requestedPredicate.nonRevoked,
            restrictions: requestedPredicate.restrictions
          };
          index++;
        });
      }
    });
    return {
      anoncreds: {
        name: template.name,
        version: template.version,
        nonce: Date.now().toString(),
        requested_attributes: requestedAttributes,
        requested_predicates: requestedPredicates
      }
    };
  }
  if (template.payload.type === _proofReqeustTemplate.ProofRequestType.DIF) {
    return {};
  }
};
exports.buildProofRequestDataForTemplate = buildProofRequestDataForTemplate;
/*
 * Create connectionless proof request invitation for provided template
 * */
const createConnectionlessProofRequestInvitation = async (agent, template, customPredicateValues) => {
  const proofFormats = buildProofRequestDataForTemplate(template, customPredicateValues);
  if (!proofFormats) {
    return undefined;
  }
  const {
    message: request,
    proofRecord
  } = await agent.proofs.createRequest({
    protocolVersion,
    autoAcceptProof: _core.AutoAcceptProof.Always,
    proofFormats
  });
  const {
    message: invitation,
    invitationUrl
  } = await agent.oob.createLegacyConnectionlessInvitation({
    recordId: proofRecord.id,
    message: request,
    domain
  });
  return {
    request,
    proofRecord,
    invitation,
    invitationUrl
  };
};
exports.createConnectionlessProofRequestInvitation = createConnectionlessProofRequestInvitation;
/*
 * Build Proof Request for provided template and send it to provided connection
 * */
const sendProofRequest = async (agent, template, connectionId, customPredicateValues) => {
  const proofFormats = buildProofRequestDataForTemplate(template, customPredicateValues);
  if (!proofFormats) {
    return undefined;
  }
  const proofRecord = await agent.proofs.requestProof({
    protocolVersion,
    connectionId,
    proofFormats
  });
  return {
    proofRecord
  };
};

/*
 * Check if the Proof Request template contains at least one predicate
 * */
exports.sendProofRequest = sendProofRequest;
const hasPredicates = record => {
  if (record.payload.type === _proofReqeustTemplate.ProofRequestType.AnonCreds) {
    return record.payload.data.some(d => {
      var _d$requestedPredicate;
      return d.requestedPredicates && ((_d$requestedPredicate = d.requestedPredicates) === null || _d$requestedPredicate === void 0 ? void 0 : _d$requestedPredicate.length) > 0;
    });
  }
  if (record.payload.type === _proofReqeustTemplate.ProofRequestType.DIF) {
    return false;
  }
  return false;
};

/*
 * Check if the Proof Request template contains parameterizable predicates
 * */
exports.hasPredicates = hasPredicates;
const isParameterizable = record => {
  if (record.payload.type === _proofReqeustTemplate.ProofRequestType.AnonCreds) {
    return record.payload.data.some(d => {
      var _d$requestedPredicate2;
      return (_d$requestedPredicate2 = d.requestedPredicates) === null || _d$requestedPredicate2 === void 0 ? void 0 : _d$requestedPredicate2.some(predicate => predicate.parameterizable);
    });
  }
  if (record.payload.type === _proofReqeustTemplate.ProofRequestType.DIF) {
    return false;
  }
  return false;
};
exports.isParameterizable = isParameterizable;
//# sourceMappingURL=proof-request.js.map